import tkinter as tk
# Create the root window
root = tk.Tk()

# set the title
root.title('Course Preference Survey')

# set the root window size

root.geometry('640x480+300+300')
root.resizable(False, False)

###########
# Widgets #
###########

# Use a Label to show the title
# 'font' lets us set a font
title = tk.Label(root, text='Please take the survey', font = ("Arial", 16, "bold"),bg='brown',
  fg='#FF0' )#bg = 'orchid1',fg='black')

# Use string vars for strings
name_var = tk.StringVar(root)
name_label = tk.Label(root, text='What is your name?')
name_inp = tk.Entry(root, textvariable=name_var)

# Use boolean var for True/False
student_status_var = tk.BooleanVar()
student_status_inp = tk.Checkbutton(root, variable=student_status_var, text='Check this box if you are current student.')

# Use int var for whole numbers
# Value can set a default
num_var = tk.IntVar(value=1)
num_label = tk.Label(text='How many papers are you currently doing ?')
# note that even with an intvar, the key is still 'textvariable'
num_inp = tk.Spinbox(root,textvariable=num_var,from_=0,to=1000,increment=1)

# Listboxes don't work well with variables,
# However OptionMenu works great!
course_var = tk.StringVar(value='Any')
most_intersting_course_label = tk.Label(root,text='What paper is most interesting to you?')
course_choices = ('Game Programming', 'Data Science', 'Cloud Computing', 'Network Admin', 'Investigative Studio', 'AI', 'Cybersecurity')
course_inp = tk.OptionMenu(root, course_var, *course_choices)

course_label = tk.Label(root, text='Are you Currenly in Studying for Diploma in Software Engineering?')
# Use a Frame to keep widgets together
course_frame = tk.Frame(root)

# We can use any kind of var with Radiobuttons,
# as long as each button's 'value' property is the
# correct type
dse_status_var = tk.BooleanVar()
# The radio buttons are connected by using the same variable
# The value of the var will be set to the button's 'value' property value
doing_dse_inp = tk.Radiobutton(course_frame, text='Yes',value=True,variable=dse_status_var)
notdoing_dse_inp = tk.Radiobutton(course_frame, text='No',value=False,variable=dse_status_var)

# The Text widget doesn't support variables, sadly
# There is no analogous widget that does
addtional_info_label = tk.Label(root, text='Provide a Reason why the Selected Course is Most Interesting')
addtional_info_inp = tk.Text(root, height=3)

# Buttons are used to trigger actions
submit_btn = tk.Button(root, text='Submit Survey',font = ("Verdana", 12, "bold"))

# Labels can use a StringVar for their contents
output_var = tk.StringVar(value='')
output_line = tk.Label(root,textvariable=output_var,anchor='w',justify='left')

#######################
# Geometry Management #
#######################
# Using Grid instead of pack
# Put our widgets on the root window
title.grid()
# columnspan allows the widget to span multiple columns
title.grid(columnspan=2)

# add name label and input
# Column defaults to 0
name_label.grid(row=1, column=0)

# The grid automatically expands
# when we add a widget to the next row or column
name_inp.grid(row=1, column=1)

# 'sticky' attaches the widget to the named sides,
# so it will expand with the grid
student_status_inp.grid(row=2, columnspan=2, sticky='we')
# tk constants can be used instead of strings
num_label.grid(row=3, sticky=tk.W)
num_inp.grid(row=3, column=1, sticky=(tk.W + tk.E))

#padx and pady can still be used to add horizontal or vertical padding
most_intersting_course_label.grid(row=4, columnspan=2, sticky=tk.W, pady=10)
course_inp.grid(row=5, columnspan=2, sticky=tk.W + tk.E, padx=25)

# We can still use pack on the plantain frame.
# pack and grid can be mixed in a layout as long as we don't
# use them in the same frame
doing_dse_inp.pack(side='left', fill='x', ipadx=10, ipady=5)
notdoing_dse_inp.pack(side='left', fill='x', ipadx=10, ipady=5)
course_label.grid(row=6, columnspan=2, sticky=tk.W)
course_frame.grid(row=7, columnspan=2, stick=tk.W)

# Sticky on all sides will allow the widget to fill vertical and horizontal
addtional_info_label.grid(row=8, sticky=tk.W)
addtional_info_inp.grid(row=9, columnspan=2, sticky='NSEW')

# Add the button and output
submit_btn.grid(row=99)
output_line.grid(row=100, columnspan=2, sticky='NSEW')

# columnconfigure can be used to set options on the columns of the grid
# 'weight' means that column will be preferred for expansion
root.columnconfigure(1, weight=1)

# rowconfigure works for rows
root.rowconfigure(99, weight=2)
root.rowconfigure(100, weight=1)

#####################
# Add some behavior #
#####################

def on_submit():
  """To be run when the user submits the form"""

  # Vars all use 'get()' to retreive their variables
  name = name_var.get()
  # Because we used an IntVar, .get() will try to convert
  # the contents of num_var to int.
  try:
    number = num_var.get()
  except tk.TclError:
    number = 10000

  # With the variable, OptionMenu makes things simple
  course = course_var.get()

  # Checkbutton and Radiobutton values are now simple
  student_status = student_status_var.get()
  # Text widgets require a range
  add_info = addtional_info_inp.get('1.0', tk.END)

  # Update the text in our output
  message = f'Thanks for taking the survey, {name}.\n'
  if not student_status:
    message += "Sorry you are not a current Diploma in Software Engineering student!\n"
  else:
    message += f'You are currently involved in {number} courses. \nHowever, you have indicated that {course} is the most interesting course!\n'
  if add_info.strip():
    message += f'\n\nYour main reason why the course {course} is most interesting is below :\n{add_info}'

  # Set the value of a variable using .set()
  # DON'T DO THIS:  output_var = 'my string'
  output_var.set(message)

# configure the button to trigger submission
submit_btn.configure(command=on_submit)

###############
# Execute App #
###############

root.mainloop()